@@ -1,9 +1,10 @@
 #!/usr/bin/env -S deno run --unstable --allow-run --allow-read --allow-write --allow-env
 // Copyright 2018-2021 the Deno authors. All rights reserved. MIT license.
 
-import * as colors from "https://deno.land/std@0.103.0/fmt/colors.ts";
-import { copy } from "https://deno.land/std@0.103.0/fs/copy.ts";
-import { emptyDir } from "https://deno.land/std@0.103.0/fs/empty_dir.ts";
+import * as colors from "https://deno.land/std@0.106.0/fmt/colors.ts";
+import { copy } from "https://deno.land/std@0.106.0/fs/copy.ts";
+import { emptyDir } from "https://deno.land/std@0.106.0/fs/empty_dir.ts";
+import * as path from "https://deno.land/std@0.106.0/path/mod.ts";
 
 await Deno.permissions.request({ name: "env" });
 await Deno.permissions.request({ name: "run" });
@@ -15,7 +16,7 @@ console.log(
 );
 
 const home = Deno.env.get("HOME");
-const root = new URL(".", import.meta.url).pathname;
+const root = path.dirname(path.fromFileUrl(import.meta.url));
 const copyrightHeader = `// Copyright 2018-${
   new Date().getFullYear()
 } the Deno authors. All rights reserved. MIT license.`;
